@@ -14,7 +14,11 @@
 # limitations under the License.
 
 import logging
-from StringIO import StringIO
+import sys
+if sys.version_info[0] < 3:
+    from StringIO import StringIO
+else:
+    from io import StringIO
 from collections import deque
 
 from gi.repository import Gio
@@ -97,7 +101,7 @@ class Session(GObject.GObject):
                 if self._parse_g is None:
                     self._parse_g = protocol.parse_message(self._message)
 
-                parsed_message = self._parse_g.next()
+                parsed_message = next(self._parse_g)
                 if parsed_message:
                     self._parse_g = None
 
@@ -105,11 +109,12 @@ class Session(GObject.GObject):
                     if parsed_message.tp == protocol.OPCODE_TEXT:
                         received = Message(Message.TYPE_TEXT,
                                            parsed_message.data)
-                        logger.debug("Text message %s" % received.data)
+                        logger.debug("Received text message %s" %
+                                     received.data)
                     elif parsed_message.tp == protocol.OPCODE_BINARY:
                         received = Message(Message.TYPE_BINARY,
                                            parsed_message.data)
-                        logger.debug("Binary message, length %s" %
+                        logger.debug("Received binary message, length %s" %
                                      len(received.data))
                     if received:
                         self.message_received.emit(received)
@@ -132,6 +137,11 @@ class Session(GObject.GObject):
         self._send_from_queue()
 
     def send_message(self, message, callback=None, binary=False):
+        if binary:
+            logger.debug("Sending binary message, length %s" % len(message))
+        else:
+            logger.debug("Sending text message %s" % message)
+
         protocol_message = protocol.make_message(message, binary)
         self._send_queue.append((protocol_message, callback))
         self._send_from_queue()
@@ -177,7 +187,7 @@ if __name__ == "__main__":
     server.connect("session-started", session_started_cb)
     port = server.start()
 
-    print "Listening on port %d" % port
+    print("Listening on port %d" % port)
 
     main_loop = GLib.MainLoop()
     main_loop.run()
